Files
TheRock/rocm-systems/experimental/perf-dkms/test_apps/cache_miss/cache_miss.cpp
T
derek.holloway 7502bf64a4
CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
Flatten subprojects into a single base monorepo
2026-09-02 16:34:47 -07:00

70 lines
2.1 KiB
C++

#include "test_framework.hpp"
#include <vector>
// L2 cache miss test - large streaming access
// Targets GL2C miss counters
__global__ void cache_miss_kernel(float* output, const float* input, size_t large_size) {
int idx = blockIdx.x * blockDim.x + threadIdx.x;
float sum = 0.0f;
// Streaming access through large array to maximize cache misses
size_t stride = blockDim.x * gridDim.x;
#pragma unroll 1
for (int i = 0; i < 100; i++) {
size_t read_idx = (idx + i * stride) % large_size;
sum += input[read_idx];
}
output[idx] = sum;
}
class CacheMissTest : public test_framework::TestBase {
public:
CacheMissTest() : TestBase("Cache Miss - L2 Cache Misses") {}
bool setup() override {
// Large working set that doesn't fit in L2 cache
large_size_ = 64 * 1024 * 1024; // 64M floats = 256 MB
output_size_ = 1024 * 1024; // 1M threads
// Allocate device memory
d_input_ = hip_utils::allocateDeviceWithValue<float>(large_size_, 1.0f);
d_output_ = hip_utils::allocateDevice<float>(output_size_);
std::cout << " Large working set: " << large_size_ << " floats ("
<< (large_size_ * sizeof(float) / (1024*1024)) << " MB)" << std::endl;
std::cout << " Output size: " << output_size_ << " elements" << std::endl;
std::cout << " Access pattern: Streaming (strided)" << std::endl;
std::cout << " Expected behavior: High L2 cache miss rate" << std::endl;
return true;
}
bool execute() override {
dim3 block_size(256);
dim3 grid_size((output_size_ + block_size.x - 1) / block_size.x);
test_framework::KernelRunner runner("cache_miss_kernel", grid_size, block_size);
runner.launch(cache_miss_kernel, d_output_, d_input_, large_size_);
return true;
}
void cleanup() override {
hip_utils::freeDevice(d_input_);
hip_utils::freeDevice(d_output_);
}
private:
float* d_input_ = nullptr;
float* d_output_ = nullptr;
size_t large_size_;
size_t output_size_;
};
int main() {
CacheMissTest test;
return test.run();
}